Helps administer iServ school servers that are popular in Germany

Eine Sammlung von Tools, die das Verwalten der Benutzer und der Gruppen erleichtert. Dies erfolgt erstens durch Import von Schüler- und Lehrerdaten CSV-Dateien (aus SiBank) und durch Export von CSV-Dateien für das Import-Modul von iServ. Zweitens können über einen ferngesteuerten Chrome-Browser weitere Einstellungen übernommen werden.